Summary: Utilities for managing accounts and shadow password files
Name: shadow-utils
Version: 4.14.1
Release: 1%{?dist}
License: BSD and GPLv2+
URL: https://github.com/shadow-maint/shadow
Source0: https://github.com/shadow-maint/shadow/releases/download/%{version}/shadow-%{version}.tar.xz
Source1: shadow-utils.useradd
Source2: shadow-utils.login.defs

Patch5000: add-sm3-support.patch

BuildRequires: autoconf, automake, gcc, make, libtool
BuildRequires: libacl-devel, libattr-devel, libeconf-devel
BuildRequires: libselinux-devel >= 1.25.2-1, libsemanage-devel, audit-libs-devel >= 1.6.5
Requires: audit-libs >= 1.6.5, libselinux >= 1.25.2-1, setup
Provides: shadow = %{version}-%{release}

%description
The shadow-utils package includes the necessary programs for
converting UNIX password files to the shadow password format, plus
programs for managing user and group accounts. The pwconv command
converts passwords to the shadow password format. The pwunconv command
unconverts shadow passwords and generates a passwd file (a standard
UNIX password file). The pwck command checks the integrity of password
and shadow files. The lastlog command prints out the last login times
for all users. The useradd, userdel, and usermod commands are used for
managing user accounts. The groupadd, groupdel, and groupmod commands
are used for managing group accounts.


%package subid
Summary: A library to manage subordinate uid and gid ranges

%description subid
This package provides a way to manage subid ranges.


%package subid-devel
Summary: Development package for shadow-utils-subid
Requires: %{name}-subid

%description subid-devel
This package provides header files and dso for developers who use
shadow-utils-subid.

%prep
%autosetup -n shadow-%{version} -p1

%build
export CFLAGS="$RPM_OPT_FLAGS -fpie"
export LDFLAGS="-pie -Wl,-z,relro -Wl,-z,now"

autoreconf
%configure \
        --enable-shadowgrp \
        --with-audit \
        --with-sha-crypt \
        --with-sm3-crypt \
        --with-bcrypt \
        --with-yescrypt \
        --with-selinux \
        --without-libbsd \
        --without-libcrack \
        --without-libpam \
        --enable-shared \
        --with-group-name-max-length=32 \
        --enable-lastlog \
        --enable-logind=no
%make_build

%install
%make_install gnulocaledir=%{buildroot}%{_datadir}/locale MKINSTALLDIRS=`pwd`/mkinstalldirs
install -m755 -d %{buildroot}%{_sysconfdir}/default
install -pm644 %{SOURCE2} %{buildroot}%{_sysconfdir}/login.defs
install -pm600 %{SOURCE1} %{buildroot}%{_sysconfdir}/default/useradd

%make_install -C man install-man

rm %{buildroot}%{_bindir}/chfn
rm %{buildroot}%{_bindir}/chsh
rm %{buildroot}%{_bindir}/expiry
rm %{buildroot}%{_bindir}/groups
rm %{buildroot}%{_bindir}/login
rm %{buildroot}%{_bindir}/passwd
rm %{buildroot}%{_bindir}/su
rm %{buildroot}%{_bindir}/faillog
rm %{buildroot}%{_sysconfdir}/login.access
rm %{buildroot}%{_sysconfdir}/limits
rm %{buildroot}%{_sbindir}/logoutd
rm %{buildroot}%{_sbindir}/nologin
rm %{buildroot}%{_mandir}/man1/chfn.*
rm %{buildroot}%{_mandir}/*/man1/chfn.*
rm %{buildroot}%{_mandir}/man1/chsh.*
rm %{buildroot}%{_mandir}/*/man1/chsh.*
rm %{buildroot}%{_mandir}/man1/expiry.*
rm %{buildroot}%{_mandir}/*/man1/expiry.*
rm %{buildroot}%{_mandir}/man1/groups.*
rm %{buildroot}%{_mandir}/*/man1/groups.*
rm %{buildroot}%{_mandir}/man1/login.*
rm %{buildroot}%{_mandir}/*/man1/login.*
rm %{buildroot}%{_mandir}/man1/passwd.*
rm %{buildroot}%{_mandir}/*/man1/passwd.*
rm %{buildroot}%{_mandir}/man1/su.*
rm %{buildroot}%{_mandir}/*/man1/su.*
rm %{buildroot}%{_mandir}/man5/limits.*
rm %{buildroot}%{_mandir}/*/man5/limits.*
rm %{buildroot}%{_mandir}/man5/login.access.*
rm %{buildroot}%{_mandir}/*/man5/login.access.*
rm %{buildroot}%{_mandir}/man5/passwd.*
rm %{buildroot}%{_mandir}/*/man5/passwd.*
rm %{buildroot}%{_mandir}/man5/porttime.*
rm %{buildroot}%{_mandir}/*/man5/porttime.*
rm %{buildroot}%{_mandir}/man5/suauth.*
rm %{buildroot}%{_mandir}/*/man5/suauth.*
rm %{buildroot}%{_mandir}/man8/logoutd.*
rm %{buildroot}%{_mandir}/*/man8/logoutd.*
rm %{buildroot}%{_mandir}/man8/nologin.*
rm %{buildroot}%{_mandir}/*/man8/nologin.*
rm %{buildroot}%{_mandir}/man3/getspnam.*
rm %{buildroot}%{_mandir}/*/man3/getspnam.*
rm %{buildroot}%{_mandir}/man5/faillog.*
rm %{buildroot}%{_mandir}/*/man5/faillog.*
rm %{buildroot}%{_mandir}/man8/faillog.*
rm %{buildroot}%{_mandir}/*/man8/faillog.*

rm -f %{buildroot}/%{_libdir}/libsubid.{la,a}

find %{buildroot}%{_mandir} -depth -type d -empty -delete

%find_lang shadow

for dir in $(ls -1d %{buildroot}%{_mandir}/{??,??_??}) ; do
    dir=$(echo $dir | sed -e "s|^%{buildroot}||")
    lang=$(basename $dir)
    echo "%%lang($lang) $dir/man*/*" >> shadow.man
done

mkdir -p %{buildroot}/%{_includedir}/shadow
install -m 644 libsubid/subid.h %{buildroot}/%{_includedir}/shadow/


%files -f shadow.lang -f shadow.man
%license COPYING
%doc NEWS doc/HOWTO README
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/login.defs
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/default/useradd
%attr(4755,root,root) %{_bindir}/chage
%attr(4755,root,root) %{_bindir}/gpasswd
%attr(4755,root,root) %{_bindir}/newgrp
%attr(0755,root,root) %caps(cap_setgid=ep) %{_bindir}/newgidmap
%attr(0755,root,root) %caps(cap_setuid=ep) %{_bindir}/newuidmap
%attr(0755,root,root) %{_sbindir}/user*
%attr(0755,root,root) %{_sbindir}/group*
%{_bindir}/sg
%{_bindir}/lastlog
%{_sbindir}/grpck
%{_sbindir}/pwck
%{_sbindir}/*conv
%{_sbindir}/chpasswd
%{_sbindir}/chgpasswd
%{_sbindir}/newusers
%{_sbindir}/vipw
%{_sbindir}/vigr
%{_mandir}/man1/chage.1*
%{_mandir}/man1/gpasswd.1*
%{_mandir}/man1/sg.1*
%{_mandir}/man1/newgrp.1*
%{_mandir}/man1/newgidmap.1*
%{_mandir}/man1/newuidmap.1*
%{_mandir}/man3/shadow.3*
%{_mandir}/man5/shadow.5*
%{_mandir}/man5/login.defs.5*
%{_mandir}/man5/gshadow.5*
%{_mandir}/man5/subuid.5*
%{_mandir}/man5/subgid.5*
%{_mandir}/man8/group*.8*
%{_mandir}/man8/user*.8*
%{_mandir}/man8/pwck.8*
%{_mandir}/man8/grpck.8*
%{_mandir}/man8/chpasswd.8*
%{_mandir}/man8/chgpasswd.8*
%{_mandir}/man8/newusers.8*
%{_mandir}/man8/*conv.8*
%{_mandir}/man8/lastlog.8*
%{_mandir}/man8/vipw.8*
%{_mandir}/man8/vigr.8*

%files subid
%{_bindir}/getsubids
%{_libdir}/libsubid.so.*
%{_mandir}/man1/getsubids.1*

%files subid-devel
%{_includedir}/shadow/subid.h
%{_libdir}/libsubid.so

%changelog
* Thu Jan 04 2024 Upgrade Robot <upbot@opencloudos.org> - 4.14.1-1
- Upgrade to version 4.14.1

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.13-2
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Jul 28 2023 Miaojun Dong <zoedong@tencent.com> - 4.13-1
- Bump version to 4.13

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.11.1-7
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.11.1-6
- Rebuilt for OpenCloudOS Stream 23

* Thu Mar 30 2023 Xiaojie Chen <jackxjchen@tencent.com> - 4.11.1-5
- use relaxed usernames

* Mon Mar 20 2023 Miaojun Dong <zoedong@tencent.com> - 4.11.1-4
- fix SM3 crypt prefix

* Tue Feb 21 2023 Miaojun Dong <zoedong@tencent.com> - 4.11.1-3
- add sm3 support

* Mon Dec 26 2022 Shuo Wang <abushwang@tencent.com> - 4.11.1-2
- add requires for subid-devel

* Thu Jun 9 2022 cunshunxia <cunshunxia@tencent.com> - 4.11.1-1
- initial build
